@@ -49,9 +49,9 @@ class distfit():
         Upperbounds = 'up', 'high' or 'right', whereas lowerbounds = 'down', 'low' or 'left'
     distr : str, default: 'popular'
         The (set) of distribution to test. A set of distributions can be tested by:
-        'popular', 'full', or specify the theoretical distribution: 'norm', 't'.
-        for discrete distributions; binomial is used.
-        See docs for more information about 'popular' and 'full'. https://erdogant.github.io/distfit
+        'popular', 'full', or specify the theoretical distribution: 'norm', 't' or in a list ['norm', 't', ..']
+        if method="discrete", then binomial is used.
+        See docs for more information about 'popular' and 'full': https://erdogant.github.io/distfit/pages/html/Parametric.html
     smooth : int, default: None
         Smoothing the histogram can help to get a better fit when there are only few samples available.
     stats : str, default: 'RSS'
@@ -77,12 +77,12 @@ class distfit():
         Number of bins specified to create histogram.
     bound : str
         Specified testing directionality of the distribution.
-    distr : str
+    distr : str or list of strings
         Specified distribution or a set of distributions.
     multtest : str
         Specified multiple test correction method.
     todf : Bool (default: False)
-        Output results in pandas dataframe (when True, note that this will slow down the code significantly)
+        Output results in pandas dataframe when True. Note that creating pandas dataframes makes the code run significantly slower!
 
     Example
     -------
@@ -220,7 +220,7 @@ class distfit():
             self.summary = out_summary
         elif self.method=='discrete':
             # Compute best distribution fit on the empirical X
-            model, figdata = fit_transform_binom(X, f=self.f, weighted=True, verbose=verbose)
+            model, figdata = fit_transform_binom(X, f=self.f, weighted=True, stats=self.stats, verbose=verbose)
             model = _compute_cii(self, model, verbose=verbose)
             # self.histdata = (figdata['Xdata'], figdata['hist'])
             self.model = model
@@ -268,6 +268,8 @@ class distfit():
             total number of elements in for data X
 
         """
+        # Clean readily fitted models to ensure correct results.
+        self._clean(verbose=verbose)
         # Fit model to get list of distributions to check
         self.fit(verbose=verbose)
         # Transform X based on functions
@@ -292,6 +294,15 @@ class distfit():
         # Return
         return results
 
+    def _clean(self, verbose=3):
+        # Clean readily fitted models to ensure correct results.
+        if hasattr(self, 'model'):
+            if verbose>=3: print('[distfit] >Cleaning previous fitted model results..')
+            if hasattr(self, 'histdata'): del self.histdata
+            if hasattr(self, 'model'): del self.model
+            if hasattr(self, 'summary'): del self.summary
+            if hasattr(self, 'size'): del self.size
+
     def predict(self, y, verbose=3):
         """Compute probability for response variables y, using the specified method.
 
@@ -326,10 +337,11 @@ class distfit():
         if 'numpy.ndarray' not in str(type(y)): raise Exception('y should be of type np.array or list')
         if verbose>=3: print('[distfit] >predict..')
 
-        if self.method=='parametric':
-            out = _predict(self, y, verbose=verbose)
-        elif self.method=='discrete':
+        if (self.method=='parametric') or (self.method=='discrete'):
+        # if self.method=='parametric':
             out = _predict(self, y, verbose=verbose)
+        # elif self.method=='discrete':
+            # out = _predict(self, y, verbose=verbose)
         elif self.method=='quantile':
             out = _predict_quantile(self, y, verbose=verbose)
         elif self.method=='percentile':
@@ -339,8 +351,21 @@ class distfit():
         # Return
         return out
 
+    def generate(self, n, random_state=None, verbose=3):
+        """Generate new samples based on the fitted distribution."""
+        if not hasattr(self, 'model'): raise Exception('[distfit] Error in generate: A model is required. Try fitting first on your data using fit_transform(X)')
+        if verbose>=3: print('[distfit] >Generate %s %s distributed samples with fitted params %s.' %(n, self.model['name'], str(self.model['params'])))
+        X = None
+
+        if (self.method=='parametric') or (self.method=='discrete'):
+            X = self.model['model'].rvs(size=n, random_state=random_state)
+        else:
+            if verbose>=3: print('[distfit] >Warning: nothing to generate. Method should be of type: "parametric" or "discrete"')
+        # Return
+        return X
+
     # Plot
-    def plot(self, title='', figsize=(10, 8), xlim=None, ylim=None, verbose=3):
+    def plot(self, title='', figsize=(10, 8), xlim=None, ylim=None, fig=None, ax=None, verbose=3):
         """Make plot.
 
         Parameters
@@ -353,6 +378,10 @@ class distfit():
             Limit figure in x-axis.
         ylim : Float, optional (default: None)
             Limit figure in y-axis.
+        fig : Figure, optional (default: None)
+            Matplotlib figure (Note - ignored when method is `discrete`)
+        ax : Axes, optional (default: None)
+            Matplotlib Axes object (Note - ignored when method is `discrete`)
         verbose : Int [1-5], optional (default: 3)
             Print information to screen.
 
@@ -364,13 +393,13 @@ class distfit():
         if not hasattr(self, 'model'): raise Exception('[distfit] Error in plot: For plotting, A model is required. Try fitting first on your data using fit_transform(X)')
         if verbose>=3: print('[distfit] >plot..')
         if (self.method=='parametric'):
-            fig, ax = _plot_parametric(self, title=title, figsize=figsize, xlim=xlim, ylim=ylim, verbose=verbose)
+            fig, ax = _plot_parametric(self, title=title, figsize=figsize, xlim=xlim, ylim=ylim, fig=fig, ax=ax, verbose=verbose)
         elif (self.method=='discrete'):
             fig, ax = plot_binom(self, title=title, figsize=figsize, xlim=xlim, ylim=ylim, verbose=verbose)
         elif (self.method=='quantile'):
-            fig, ax = _plot_quantile(self, title=title, figsize=figsize, xlim=xlim, ylim=ylim, verbose=verbose)
+            fig, ax = _plot_quantile(self, title=title, figsize=figsize, xlim=xlim, ylim=ylim, fig=fig, ax=ax, verbose=verbose)
         elif (self.method=='percentile'):
-            fig, ax = _plot_quantile(self, title=title, figsize=figsize, xlim=xlim, ylim=ylim, verbose=verbose)
+            fig, ax = _plot_quantile(self, title=title, figsize=figsize, xlim=xlim, ylim=ylim, fig=fig, ax=ax, verbose=verbose)
         else:
             if verbose>=3: print('[distfit] >Warning: nothing to plot. Method not yet implemented for %s' %(self.method))
             fig, ax = None, None
@@ -378,7 +407,7 @@ class distfit():
         return fig, ax
 
     # Plot summary
-    def plot_summary(self, n_top=None, figsize=(15, 8), ylim=None, verbose=3):
+    def plot_summary(self, n_top=None, figsize=(15, 8), ylim=None, fig=None, ax=None, verbose=3):
         """Plot summary results.
 
         Parameters
@@ -389,6 +418,10 @@ class distfit():
             The figure size.
         ylim : Float, optional (default: None)
             Limit figure in y-axis.
+        fig : Figure, optional (default: None)
+            Matplotlib figure
+        ax : Axes, optional (default: None)
+            Matplotlib Axes object
         verbose : Int [1-5], optional (default: 3)
             Print information to screen.
 
@@ -404,7 +437,9 @@ class distfit():
 
             x = self.summary['score'][0:n_top]
             labels = self.summary['distr'].values[0:n_top]
-            fig, ax = plt.subplots(figsize=figsize)
+            if ax is None:
+                fig, ax = plt.subplots(figsize=figsize)
+
             plt.plot(x)
             # You can specify a rotation for the tick labels in degrees or with keywords.
             plt.xticks(np.arange(len(x)), labels, rotation='vertical')
@@ -419,7 +454,6 @@ class distfit():
             if ylim is not None:
                 plt.ylim(ymin=ylim[0], ymax=ylim[1])
 
-            plt.show()
             return(fig, ax)
         else:
             print('[distfit] This function works only in case of method is "parametric"')
@@ -509,26 +543,26 @@ def _predict(self, y, verbose=3):
     if verbose>=4: print('[distfit] >Compute significance for y for the fitted theoretical distribution...')
     if not hasattr(self, 'model'): raise Exception('Error: Before making a prediction, a model must be fitted first using the function: fit_transform(X)')
 
-    if self.method=='discrete':
-        getdist = self.model['distr']
-        # Compute P-value for data based on null-distribution
-        getP = getdist.cdf(y)
-    else:
-        # Get distribution and the parameters
-        getdist = self.model['distr']
-        arg = self.model['params'][:-2]
-        loc = self.model['params'][-2]
-        scale = self.model['params'][-1]
-        # Compute P-value for data based on null-distribution
-        getP = getdist.cdf(y, *arg, loc, scale) if arg else getdist.pdf(y, loc, scale)
+    # if (self.method=='parametric') or (self.method=='discrete'):
+        # getdist = self.model['model']
+    # Compute P-value for data based on null-distribution
+    Pvalues = self.model['model'].cdf(y)
+    # else:
+    #     # Get distribution and the parameters
+    #     getdist = self.model['distr']
+    #     arg = self.model['params'][:-2]
+    #     loc = self.model['params'][-2]
+    #     scale = self.model['params'][-1]
+    #     # Compute P-value for data based on null-distribution
+    #     getP = getdist.cdf(y, *arg, loc, scale) if arg else getdist.cdf(y, loc, scale)
 
     # Determine P based on upper/lower/no bounds
     if self.bound=='up' or self.bound=='right' or self.bound=='high':
-        Praw = 1 - getP
+        Praw = 1 - Pvalues
     elif self.bound=='down' or self.bound=='left' or self.bound=='low':
-        Praw = getP
+        Praw = Pvalues
     elif self.bound=='both':
-        Praw = np.min([1 - getP, getP], axis=0)
+        Praw = np.min([1 - Pvalues, Pvalues], axis=0)
     else:
         raise Exception('[distfit] >Error in predict: "bounds" is not set correctly! Options are: up/down/right/left/high/low/both.')
         Praw=[]
@@ -647,8 +681,10 @@ def _predict_percentile(self, y, verbose=3):
 
 
 # Plot
-def _plot_quantile(self, title='', figsize=(15, 8), xlim=None, ylim=None, verbose=3):
-    fig, ax = plt.subplots(figsize=figsize)
+def _plot_quantile(self, title='', figsize=(15, 8), xlim=None, ylim=None, fig=None, ax=None, verbose=3):
+    if ax is None:
+        fig, ax = plt.subplots(figsize=figsize)
+
     # Plot empirical data
     ax.plot(self.histdata[1], self.histdata[0], color='k', linewidth=1, label='empirical distribution')
     # add CII
@@ -670,23 +706,22 @@ def _plot_quantile(self, title='', figsize=(15, 8), xlim=None, ylim=None, verbos
             ax.scatter(self.results['y'][idxOUT], np.zeros(sum(idxOUT)), color='r', marker='x', alpha=0.8, linewidth=1.5, label='Inside boundaries')
 
     # Limit axis
-    if xlim is not None:
-        plt.xlim(xmin=xlim[0], xmax=xlim[1])
-    if ylim is not None:
-        plt.ylim(ymin=ylim[0], ymax=ylim[1])
+    if xlim is not None:        
+        ax.set_xlim(xlim[0], xlim[1])
+    if ylim is not None:        
+        ax.set_ylim(ylim[0], ylim[1])
 
     ax.grid(True)
     ax.set_xlabel('Values')
     ax.set_ylabel('Frequency')
     ax.set_title(title)
     ax.legend()
-    plt.show()
 
     return fig, ax
 
 
 # %% Plot
-def _plot_parametric(self, title='', figsize=(10, 8), xlim=None, ylim=None, verbose=3):
+def _plot_parametric(self, title='', figsize=(10, 8), xlim=None, ylim=None, fig=None, ax=None, verbose=3):
     # Store output and function parameters
     model = self.model
     Param = {}
@@ -717,7 +752,9 @@ def _plot_parametric(self, title='', figsize=(10, 8), xlim=None, ylim=None, verb
     y = distline.pdf(x, loc=loc, scale=scale, *arg)
     # ymax=max(self.histdata[0])
 
-    fig, ax = plt.subplots(figsize=figsize)
+    if ax is None:
+        fig, ax = plt.subplots(figsize=figsize)
+
     # Plot empirical data
     ax.plot(self.histdata[1], self.histdata[0], color='k', linewidth=1, label='empirical distribution')
     # Plot pdf
@@ -739,10 +776,10 @@ def _plot_parametric(self, title='', figsize=(10, 8), xlim=None, ylim=None, verb
     ax.set_ylabel('Frequency')
 
     # Limit axis
-    if Param['xlim'] is not None:
-        plt.xlim(xmin=Param['xlim'][0], xmax=Param['xlim'][1])
-    if Param['ylim'] is not None:
-        plt.ylim(ymin=Param['ylim'][0], ymax=Param['ylim'][1])
+    if Param['xlim'] is not None:        
+        ax.set_xlim(Param['xlim'][0], Param['xlim'][1])
+    if Param['ylim'] is not None:        
+        ax.set_ylim(Param['ylim'][0], Param['ylim'][1])
 
     # Add significant hits as line into the plot. This data is dervived from dist.proba_parametric
     if hasattr(self, 'results'):
@@ -762,7 +799,6 @@ def _plot_parametric(self, title='', figsize=(10, 8), xlim=None, ylim=None, verb
 
     ax.legend()
     ax.grid(True)
-    plt.show()
 
     if verbose>=4: print("[distfit] Estimated distribution: %s [loc:%f, scale:%f]" %(model['name'], model['params'][-2], model['params'][-1]))
     return (fig, ax)
@@ -897,15 +933,6 @@ def _compute_score_distribution(data, X, y_obs, DISTRIBUTIONS, stats, verbose=3)
 
                 logLik = np.nan
 
-                # try:
-                #     logLik = -np.sum( distribution.logpdf(y_obs, loc=loc, scale=scale) )
-                # except Exception:
-                #     pass
-                # if len(params)>2:
-                #     logLik = -np.sum( distribution.logpdf(y_obs, arg=arg, loc=loc, scale=scale) )
-                # else:
-                #     logLik = -np.sum( distribution.logpdf(y_obs, loc=loc, scale=scale) )
-
                 # Store results
                 df.values[i, 0] = distribution.name
                 df.values[i, 1] = score
@@ -919,6 +946,7 @@ def _compute_score_distribution(data, X, y_obs, DISTRIBUTIONS, stats, verbose=3)
                     best_score = score
                     model['name'] = distribution.name
                     model['distr'] = distribution
+                    model['model'] = distribution(*arg, loc, scale) if arg else distribution(loc, scale)  # Store the fitted model
                     model['params'] = params
                     model['score'] = score
                     model['loc'] = loc
@@ -947,26 +975,32 @@ def _compute_score_distribution(data, X, y_obs, DISTRIBUTIONS, stats, verbose=3)
 def _compute_cii(self, model, verbose=3):
     if verbose>=3: print("[distfit] >Compute confidence interval [%s]" %(self.method))
     CIIup, CIIdown = None, None
-    if self.method=='parametric':
+
+    if (self.method=='parametric') or (self.method=='discrete'):
         # Separate parts of parameters
-        arg = model['params'][:-2]
-        loc = model['params'][-2]
-        scale = model['params'][-1]
+        # arg = model['params'][:-2]
+        # loc = model['params'][-2]
+        # scale = model['params'][-1]
+        # dist = getattr(st, model['name'])
+        # dist = model['distr']
+        # Get fitted model
+        # distr = model['model']
 
         # Determine %CII
-        dist = getattr(st, model['name'])
         if self.alpha is not None:
             if self.bound=='up' or self.bound=='both' or self.bound=='right' or self.bound=='high':
-                CIIdown = dist.ppf(1 - self.alpha, *arg, loc=loc, scale=scale) if arg else dist.ppf(1 - self.alpha, loc=loc, scale=scale)
+                # CIIdown = distr.ppf(1 - self.alpha, *arg, loc=loc, scale=scale) if arg else distr.ppf(1 - self.alpha, loc=loc, scale=scale)
+                CIIdown = model['model'].ppf(1 - self.alpha)
             if self.bound=='down' or self.bound=='both' or self.bound=='left' or self.bound=='low':
-                CIIup = dist.ppf(self.alpha, *arg, loc=loc, scale=scale) if arg else dist.ppf(self.alpha, loc=loc, scale=scale)
-    elif self.method=='discrete':
-        dist = model['distr']
-        if self.alpha is not None:
-            if self.bound=='up' or self.bound=='both' or self.bound=='right' or self.bound=='high':
-                CIIdown = dist.ppf(1 - self.alpha)
-            if self.bound=='down' or self.bound=='both' or self.bound=='left' or self.bound=='low':
-                CIIup = dist.ppf(self.alpha)
+                # CIIup = distr.ppf(self.alpha, *arg, loc=loc, scale=scale) if arg else distr.ppf(self.alpha, loc=loc, scale=scale)
+                CIIup = model['model'].ppf(self.alpha)
+    # elif self.method=='discrete':
+    #     distr = model['model']
+    #     if self.alpha is not None:
+    #         if self.bound=='up' or self.bound=='both' or self.bound=='right' or self.bound=='high':
+    #             CIIdown = distr.ppf(1 - self.alpha)
+    #         if self.bound=='down' or self.bound=='both' or self.bound=='left' or self.bound=='low':
+    #             CIIup = distr.ppf(self.alpha)
     elif self.method=='quantile':
         X = model
         model = {}
@@ -988,7 +1022,7 @@ def _compute_cii(self, model, verbose=3):
         # Store
         # model['samples'] = samples
     else:
-        raise Exception('[distfit] >Error: method parameter can only be "parametric", "quantile" or "percentile".')
+        raise Exception('[distfit] >Error: method parameter can only be of type: "parametric", "quantile", "percentile" or "discrete".')
 
     # Store
     model['CII_min_alpha'] = CIIup
@@ -1112,7 +1146,7 @@ class BinomPMF:
         return st.binom(self.n, p).pmf(ks)
 
 
-def transform_binom(hist, plot=True, weighted=True, f=1.5, verbose=3):
+def transform_binom(hist, plot=True, weighted=True, f=1.5, stats='RSS', verbose=3):
     """Fit histogram to binomial distribution.
 
     Parameters
@@ -1121,7 +1155,7 @@ def transform_binom(hist, plot=True, weighted=True, f=1.5, verbose=3):
         histogram as int array with counts, array index as bin.
     weighted : Bool, (default: True)
         In principle, the most best fit will be obtained if you set weighted=True.
-        However, using different measures, such as minimum sum of squared errors (SSE) as a metric; you can set weighted=False.
+        However, using different measures, such as minimum residual sum of squares (RSS) as a metric; you can set weighted=False.
     f : float, (default: 1.5)
         try to fit n in range n0/f to n0*f where n0 is the initial estimate.
 
@@ -1132,8 +1166,8 @@ def transform_binom(hist, plot=True, weighted=True, f=1.5, verbose=3):
             fitted binomial model.
         name : String
             Name of the fitted distribution.
-        SSE : float
-            Best SSE score
+        RSS : float
+            Best RSS score
         n : int
             binomial n value.
         p : float
@@ -1143,7 +1177,7 @@ def transform_binom(hist, plot=True, weighted=True, f=1.5, verbose=3):
 
     figdata : dict
         sses : array-like
-            The computed SSE scores accompanyin the various n.
+            The computed RSS scores accompanyin the various n.
         Xdata : array-like
             Input data.
         hist : array-like
@@ -1153,7 +1187,7 @@ def transform_binom(hist, plot=True, weighted=True, f=1.5, verbose=3):
         nvals : array-like
             Evaluated n's.
     """
-    Ydata = hist / hist.sum()  # probability mass function
+    y_obs = hist / hist.sum()  # probability mass function
     nk = len(hist)
     if weighted:
         sigmas = np.sqrt(hist + 0.25) / hist.sum()
@@ -1161,8 +1195,8 @@ def transform_binom(hist, plot=True, weighted=True, f=1.5, verbose=3):
         sigmas = np.full(nk, 1 / np.sqrt(nk * hist.sum()))
     Xdata = np.arange(nk)
 
-    mean = (Ydata * Xdata).sum()
-    variance = ((Xdata - mean)**2 * Ydata).sum()
+    mean = (y_obs * Xdata).sum()
+    variance = ((Xdata - mean)**2 * y_obs).sum()
 
     # initial estimate for p and search range for n
     nest = max(1, int(mean**2 /(mean - variance) + 0.5))
@@ -1173,41 +1207,51 @@ def transform_binom(hist, plot=True, weighted=True, f=1.5, verbose=3):
     if verbose>=4: print(f'[distfit] >Initial estimate: n={nest}, p={mean/nest:.3g}')
 
     # store fit results for each n
-    pvals, sses = np.zeros(num_n), np.zeros(num_n)
+    pvals, scores = np.zeros(num_n), np.zeros(num_n)
     for nval in nvals:
         # Make quess for P
         p_guess = max(0, min(1, mean / nval))
         # Fit
-        fitparams, _ = curve_fit(BinomPMF(nval), Xdata, Ydata, p0=p_guess, bounds=[0., 1.], sigma=sigmas, absolute_sigma=True)
-        # Determine SSE
+        fitparams, _ = curve_fit(BinomPMF(nval), Xdata, y_obs, p0=p_guess, bounds=[0., 1.], sigma=sigmas, absolute_sigma=True)
+        # Determine RSS
         p = fitparams[0]
-        sse = (((Ydata - BinomPMF(nval)(Xdata, p)) / sigmas)**2).sum()
+        pdf = BinomPMF(nval)(Xdata, p)
+
+        if stats=='RSS':
+            score = (((y_obs - pdf) / sigmas)**2).sum()
+        if stats=='wasserstein':
+            score = st.wasserstein_distance(y_obs, pdf)
+        if stats=='energy':
+            score = st.energy_distance(y_obs, pdf)
+        if stats=='ks':
+            score = -np.log10(st.ks_2samp(y_obs, pdf)[1])
+
         # Store
         pvals[nval - nmin] = p
-        sses[nval - nmin] = sse
-        if verbose>=4: print(f'[distfit] >[binomial] Trying n={nval} -> p={p:.3g} (initial: {p_guess:.3g}),' f' sse={sse:.3g}')
+        scores[nval - nmin] = score
+        if verbose>=4: print('[distfit] >[binomial] [%s=%.3g] Trying n=%s -> p=%.3g, (initial=%.3g)' %(stats, score, nval, p, p_guess))
 
-    n_fit = np.argmin(sses) + nmin
+    n_fit = np.argmin(scores) + nmin
     p_fit = pvals[n_fit - nmin]
-    sse = sses[n_fit - nmin]
-    chi2r = sse / (nk - 2) if nk > 2 else np.nan
-    # if verbose>=3: print(f'[distfit] >[binomial] [SSE: {sse:.3g}] [n: {n_fit}] [p: {p_fit:.6g}] ' f' [chi^2={chi2r:.3g}]')
-    if verbose>=3: print('[distfit] >[binomial] [SSE: %.3g] [n: %.2g] [p: %.6g] [chi^2: %.3g]' %(sse, n_fit, p_fit, chi2r))
+    score = scores[n_fit - nmin]
+    chi2r = score / (nk - 2) if nk > 2 else np.nan
+    if verbose>=3: print('[distfit] >[binomial] [%s=%.3g] [n=%.2g] [p=%.6g] [chi^2=%.3g]' %(stats, score, n_fit, p_fit, chi2r))
 
     # Store
     model = {}
-    model['distr'] = st.binom(n_fit, p_fit)
-    model['params'] = (n_fit, p_fit)
     model['name'] = 'binom'
-    model['SSE'] = sse
+    model['distr'] = st.binom
+    model['model'] = st.binom(n_fit, p_fit)
+    model['params'] = (n_fit, p_fit)
+    model['score'] = score
     model['chi2r'] = chi2r
     model['n'] = n_fit
     model['p'] = p_fit
     figdata = {}
-    figdata['sses'] = sses
+    figdata['scores'] = scores
     figdata['Xdata'] = Xdata
     figdata['hist'] = hist
-    figdata['Ydata'] = Ydata  # probability mass function
+    figdata['Ydata'] = y_obs  # probability mass function
     figdata['nvals'] = nvals
     # Return
     return model, figdata
@@ -1223,11 +1267,11 @@ def fit_binom(X):
     return hist
 
 
-def fit_transform_binom(X, f=1.5, weighted=True, verbose=3):
+def fit_transform_binom(X, f=1.5, weighted=True, stats='RSS', verbose=3):
     """Convert array of samples (nonnegative ints) to histogram and fit."""
     if verbose>=3: print('[distfit] >Fit using binomial distribution..')
     hist = fit_binom(X)
-    model, figdata = transform_binom(hist, f=f, weighted=weighted, verbose=verbose)
+    model, figdata = transform_binom(hist, f=f, weighted=weighted, stats=stats, verbose=verbose)
     return model, figdata
 
 
@@ -1307,11 +1351,11 @@ def plot_binom(self, title='', figsize=(10, 8), xlim=None, ylim=None, verbose=3)
 
     # Second image
     ax[1].set_xlabel('n')
-    ax[1].set_ylabel('sse')
-    plotfunc = ax[1].semilogy if figdata['sses'].max()>20 * figdata['sses'].min()>0 else ax[1].plot
-    plotfunc(figdata['nvals'], figdata['sses'], 'k-', label='SSE over n scan')
-    ax[1].vlines(n_fit, 0, figdata['sses'].max(), 'r', linestyles='dashed')
-    ax[1].hlines(model['SSE'], figdata['nvals'].min(), figdata['nvals'].max(), 'r', linestyles='dashed', label="Best SSE: %.3g" %(model['SSE']))
+    ax[1].set_ylabel(self.stats)
+    plotfunc = ax[1].semilogy if figdata['scores'].max()>20 * figdata['scores'].min()>0 else ax[1].plot
+    plotfunc(figdata['nvals'], figdata['scores'], 'k-', label=('%s over n scan' %self.stats))
+    ax[1].vlines(n_fit, 0, figdata['scores'].max(), 'r', linestyles='dashed')
+    ax[1].hlines(model['score'], figdata['nvals'].min(), figdata['nvals'].max(), 'r', linestyles='dashed', label="Best %s: %.3g" %(self.stats, model['score']))
     ax[1].legend()
     ax[1].grid(True)
     fig.show()
