@@ -10,26 +10,20 @@ import distfit
 # print(distfit.__version__)
 # print(dir(distfit))
 
-# %%
+# %% Multiple distributions as input
 from distfit import distfit
-X = np.random.normal(0, 2, 5000)
-y = [-8,-6,0,1,2,3,4,5,6]
-# dist = distfit(stats='RSS')
-# dist = distfit(stats='wasserstein')
-dist = distfit(stats='energy')
-# dist = distfit(stats='ks')
-dist.fit_transform(X)
-dist.plot_summary()
-# dist.plot()
+X = np.random.normal(0, 2, 10000)
+y = [-8, -6, 0, 1, 2, 3, 4, 5, 6]
+dist = distfit(stats='RSS', distr=['norm', 't', 'gamma'])
+results = dist.fit_transform(X)
 
-
-# %%
+# %% Discrete example
 from distfit import distfit
 from scipy.stats import binom
 # Generate random numbers
 X = binom(8, 0.5).rvs(1000)
 
-dist = distfit(method='discrete', f=1.5, weighted=True)
+dist = distfit(method='discrete', f=1.5, weighted=True, stats='wasserstein')
 model = dist.fit_transform(X, verbose=3)
 dist.plot()
 
@@ -37,6 +31,36 @@ dist.plot()
 results = dist.predict([0, 1, 10, 11, 12])
 dist.plot()
 
+# Generate samples
+Xgen = dist.generate(n=1000)
+dist.fit_transform(Xgen)
+results = dist.predict([0, 1, 10, 11, 12])
+dist.plot()
+
+# %%
+from distfit import distfit
+X = np.random.normal(0, 2, 10000)
+y = [-8, -6, 0, 1, 2, 3, 4, 5, 6]
+dist = distfit(stats='RSS', distr='full')
+# dist = distfit(stats='wasserstein')
+# dist = distfit(stats='energy')
+# dist = distfit(stats='ks')
+
+# Fit
+dist.fit_transform(X)
+dist.predict(y)
+
+dist.plot_summary()
+dist.plot()
+
+# Generate samples
+Xgen = dist.generate(n=10000)
+dist.fit_transform(Xgen)
+
+# Plot
+dist.plot_summary()
+dist.plot()
+
 
 # %% Import class
 from distfit import distfit
@@ -295,8 +319,9 @@ X = np.random.normal(10, 3, 2000)
 y = [3,4,5,6,10,11,12,18,20]
 
 # Initialize
-dist = distfit(method='percentile', alpha=0.05, todf=False)
+# dist = distfit(method='percentile', alpha=0.05, todf=False)
 # dist = distfit(method='quantile', alpha=0.05, todf=False)
+dist = distfit(method='parametric', alpha=0.05, todf=False)
 dist.fit_transform(X)
 dist.plot()
 
